Crate hadris_fat

Crate hadris_fat 

Re-exports

pub use error::FatError;
pub use error::Result;
pub use io::Cluster;
pub use read::FatFsReadExt;
pub use read::FileReader;
pub use write::FatDateTime;
pub use write::FatFsWriteExt;
pub use write::FileWriter;

Modules

error
Error types for the hadris-fat crate.
file
io
read
Read operations for FAT filesystems.
write
Write operations for FAT filesystems.

Structs

BpbExt32Flags
BPB_ExtFlags
DirEntryAttrFlags
Fat12
FAT12 table implementation.
Fat16
FAT16 table implementation.
Fat32
FatDir
FatDirIter
FatFs
FileEntry
FileSystemErrors
FileSystemWarnings
ParseInfo
RawBpb
The RawBpb struct represents the boot sector of any FAT partition
RawBpbExt16
RawBpbExt32
RawFileEntry
RawFsInfo
RawLfnEntry
A long file name entry The maximum length of a long file name is 255 characters, not including the null terminator The characters allowed extend these characters: . + , ; = [ ] Embedded paces are also allowed The name is stored in UTF-16 encoding (UNICODE) When the unicode character cannot be translated to ANSI, an underscore is used
VolumeInfo
Volume metadata from the boot sector.

Enums

DirectoryEntry
Fat
FatType
FAT filesystem type

Unions

RawDirectoryEntry