CachedFat

Struct CachedFat 

pub struct CachedFat<'a> { /* private fields */ }
Cached FAT operations that work with any FAT type.

Implementations

Source

impl<'a> CachedFat<'a>

pub fn new(cache: &'a mut FatSectorCache, fat: &Fat) -> Self

Create a new cached FAT wrapper.

pub fn next_cluster<T: Read + Seek>( &mut self, reader: &mut T, cluster: usize, ) -> Result<Option<u32>>

Get the next cluster in a chain using the cache.

pub fn read_chain<T: Read + Seek>( &mut self, reader: &mut T, start_cluster: u32, ) -> Result<Vec<u32>>

Read the entire cluster chain starting from a cluster.

This is efficient because it uses the cache to avoid repeated seeks. On a chain longer than max_cluster clusters (only possible if the FAT is corrupt and contains a loop), returns Error::ClusterLoop rather than silently returning a partial chain.

pub fn flush<T: Write + Seek>(&mut self, writer: &mut T) -> Result<()>

Flush the cache to disk.