DirectoryEntry

Enum DirectoryEntry 

pub enum DirectoryEntry {
    Entry(FileEntry),
}
A parsed FAT directory record.

Variants



Entry(FileEntry)

A file or directory entry

Implementations

Source

impl DirectoryEntry

pub fn name(&self) -> Cow<'_, str>

Get the display name of the entry. Returns the long filename if available, otherwise the short name.

Requires the alloc feature. See FileEntry::name.

pub fn as_entry(&self) -> Option<&FileEntry>

Get the file entry if this is an Entry variant