VerificationIssue

Enum VerificationIssue 

pub enum VerificationIssue {
    ClusterLoop {
        path: String,
        cluster: u32,
    },
    CrossLinkedCluster {
        cluster: u32,
        paths: Vec<String>,
    },
    OrphanedChain {
        start_cluster: u32,
        chain_length: u32,
    },
    SizeMismatch {
        path: String,
        recorded_size: usize,
        chain_size: usize,
    },
    InvalidFirstCluster {
        path: String,
        cluster: u32,
    },
    BadClusterInChain {
        path: String,
        position: u32,
        cluster: u32,
    },
    InvalidEntryName {
        parent_path: String,
        raw_name: [u8; 11],
    },
    LostClusters {
        count: u32,
    },
}
Types of verification issues that can be detected.

Variants



ClusterLoop

A cluster chain contains a loop (revisits a cluster).

Fields

path: String

File or directory path containing the loop

cluster: u32

The cluster where the loop was detected



CrossLinkedCluster

Two or more files share the same cluster (cross-linked).

Fields

cluster: u32

The shared cluster number

paths: Vec<String>

Paths of files sharing this cluster



OrphanedChain

A cluster chain exists in the FAT but is not referenced by any file.

Fields

start_cluster: u32

Starting cluster of the orphaned chain

chain_length: u32

Length of the chain in clusters



SizeMismatch

The recorded file size doesn’t match the cluster chain length.

Fields

path: String

File path

recorded_size: usize

Size recorded in the directory entry

chain_size: usize

Size implied by the cluster chain



InvalidFirstCluster

A directory entry points to an invalid cluster.

Fields

path: String

File or directory path

cluster: u32

The invalid cluster number



BadClusterInChain

The cluster chain contains a bad cluster marker.

Fields

path: String

File or directory path

position: u32

Position in the chain where the bad cluster was found

cluster: u32

The bad cluster number



InvalidEntryName

A directory entry has an invalid name.

Fields

parent_path: String

Parent directory path

raw_name: [u8; 11]

Raw bytes of the invalid name



LostClusters

Lost clusters (used in FAT but not referenced by any file).

Fields

count: u32

Number of lost clusters