Re-exports
pub use error::FatError;pub use error::Result;pub use io::Cluster;pub use read::FatFsReadExt;pub use read::FileReader;pub use write::FatDateTime;pub use write::FatFsWriteExt;pub use write::FileWriter;
Modules
- error
- Error types for the hadris-fat crate.
- file
- io
- read
- Read operations for FAT filesystems.
- write
- Write operations for FAT filesystems.
Structs
- BpbExt32
Flags - BPB_ExtFlags
- DirEntry
Attr Flags - Fat12
- FAT12 table implementation.
- Fat16
- FAT16 table implementation.
- Fat32
- FatDir
- FatDir
Iter - FatFs
- File
Entry - File
System Errors - File
System Warnings - Parse
Info - RawBpb
- The RawBpb struct represents the boot sector of any FAT partition
- RawBpb
Ext16 - RawBpb
Ext32 - RawFile
Entry - RawFs
Info - RawLfn
Entry - A long file name entry The maximum length of a long file name is 255 characters, not including the null terminator The characters allowed extend these characters: . + , ; = [ ] Embedded paces are also allowed The name is stored in UTF-16 encoding (UNICODE) When the unicode character cannot be translated to ANSI, an underscore is used
- Volume
Info - Volume metadata from the boot sector.
Enums
- Directory
Entry - Fat
- FatType
- FAT filesystem type